==> react-form-mobx-0.1.0.tgz: package/es/ArrayOf.js <==
var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _dec, _class, _class2, _temp, _class3, _class4, _temp2;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import { observer } from 'mobx-react';
import { createId as createUniqueId } from './utils';
import withFormStore from './withFormStore';
import Demon from './Demon';

var ItemGroup = (_dec = withFormStore(), _dec(_class = observer(_class = (_temp = _class2 = function (_Component) {
	_inherits(ItemGroup, _Component);

	function ItemGroup(props) {
		_classCallCheck(this, ItemGroup);

		var _this = _possibleConstructorReturn(this, (ItemGroup.__proto__ || Object.getPrototypeOf(ItemGroup)).call(this, props));

		var formStore = props.formStore,
		    name = props.name;
		var length = formStore.sourceValue.length;

		var createId = function createId() {
			return createUniqueId(name);
		};

		_this.helper = {
			createId: createId,
			push: function push() {
				return formStore.push(createId());
			},
			remove: formStore.remove,
			removeBy: function removeBy(id) {
				return function () {
					return formStore.remove(id);
				};
			}
		};

		for (var i = 0; i < length; i++) {
			_this.helper.push();
		}
		return _this;
	}

	_createClass(ItemGroup, [{
		key: 'render',
		value: function render() {
			var _props = this.props,
			    children = _props.children,
			    formStore = _props.formStore;

			return children(formStore.ids, this.helper);
		}
	}]);

	return ItemGroup;
}(Component), _class2.propTypes = {
	formStore: PropTypes.object.isRequired,
	children: PropTypes.func.isRequired,
	name: PropTypes.string.isRequired
}, _temp)) || _class) || _class);

var ArrayOf = observer(_class3 = (_temp2 = _class4 = function (_Component2) {
	_inherits(ArrayOf, _Component2);

	function ArrayOf(props) {
		_classCallCheck(this, ArrayOf);

		var _this2 = _possibleConstructorReturn(this, (ArrayOf.__proto__ || Object.getPrototypeOf(ArrayOf)).call(this, props));

		_this2.forwardedProps = {
			name: _this2.props.name
		};

		var children = props.children,
		    forwardedProps = _objectWithoutProperties(props, ['children']);

		_this2.forwardedProps = forwardedProps;
		return _this2;
	}

	_createClass(ArrayOf, [{
		key: 'render',
		value: function render() {
			var _props2 = this.props,
			    children = _props2.children,
			    name = _props2.name;

			return React.createElement(
				Demon,
				{ forwardedProps: this.forwardedProps, isObject: true, isArray: true },
				function () {
					return React.createElement(
						ItemGroup,
						{ name: name },
						children
					);
				}
			);
		}
	}]);

	return ArrayOf;
}(Component), _class4.propTypes = {
	children: PropTypes.func.isRequired,
	name: PropTypes.string.isRequired
}, _temp2)) || _class3;

export { ArrayOf as default };

==> react-form-mobx-0.6.0.tgz: package/es/ArrayOf.js <==
var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _dec, _class, _class2, _temp, _class3, _class4, _temp2;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component, Children, cloneElement } from 'react';
import PropTypes from 'prop-types';
import { observer } from 'mobx-react';
import { createId as createUniqueId, isFunction } from './utils';
import withFormStore from './withFormStore';
import Demon from './Demon';

var childrenType = PropTypes.oneOfType([PropTypes.func, PropTypes.node]).isRequired;

var ItemGroup = (_dec = withFormStore(), _dec(_class = observer(_class = (_temp = _class2 = function (_Component) {
	_inherits(ItemGroup, _Component);

	function ItemGroup(props) {
		_classCallCheck(this, ItemGroup);

		var _this = _possibleConstructorReturn(this, (ItemGroup.__proto__ || Object.getPrototypeOf(ItemGroup)).call(this, props));

		var formStore = props.formStore,
		    name = props.name,
		    children = props.children;

		var createId = function createId() {
			return createUniqueId(name);
		};
		var length = isFunction(children) ? formStore.sourceValue.length : Children.count(children);

		_this.helper = {
			createId: createId,
			push: function push() {
				return formStore.push(createId());
			},
			remove: formStore.remove,
			removeBy: function removeBy(id) {
				return function () {
					return formStore.remove(id);
				};
			}
		};

		for (var i = 0; i < length; i++) {
			_this.helper.push();
		}
		return _this;
	}

	_createClass(ItemGroup, [{
		key: 'render',
		value: function render() {
			var _props = this.props,
			    children = _props.children,
			    ids = _props.formStore.ids;

			if (isFunction(children)) return children(ids, this.helper);
			return Children.map(children, function (child, index) {
				return cloneElement(child, { name: ids[index] });
			});
		}
	}]);

	return ItemGroup;
}(Component), _class2.propTypes = {
	formStore: PropTypes.object.isRequired,
	children: childrenType,
	name: PropTypes.string.isRequired
}, _temp)) || _class) || _class);

var ArrayOf = observer(_class3 = (_temp2 = _class4 = function (_Component2) {
	_inherits(ArrayOf, _Component2);

	function ArrayOf(props) {
		_classCallCheck(this, ArrayOf);

		var _this2 = _possibleConstructorReturn(this, (ArrayOf.__proto__ || Object.getPrototypeOf(ArrayOf)).call(this, props));

		_this2.forwardedProps = {
			name: _this2.props.name
		};

		var children = props.children,
		    forwardedProps = _objectWithoutProperties(props, ['children']);

		_this2.forwardedProps = forwardedProps;
		return _this2;
	}

	_createClass(ArrayOf, [{
		key: 'getValue',
		value: function getValue() {
			return this.demon.getValue();
		}
	}, {
		key: 'setValue',
		value: function setValue(value) {
			this.demon.setValue(value);
		}
	}, {
		key: 'getPristineValue',
		value: function getPristineValue() {
			return this.demon.getPristineValue();
		}
	}, {
		key: 'setPristineValue',
		value: function setPristineValue(value) {
			this.demon.setPristineValue(value);
		}
	}, {
		key: 'getValidState',
		value: function getValidState() {
			return this.demon.getValidState();
		}
	}, {
		key: 'render',
		value: function render() {
			var _this3 = this;

			var _props2 = this.props,
			    children = _props2.children,
			    name = _props2.name;

			return React.createElement(
				Demon,
				{
					forwardedProps: this.forwardedProps,
					isObject: true,
					isArray: true,
					ref: function ref(demon) {
						return _this3.demon = demon;
					}
				},
				function () {
					return React.createElement(
						ItemGroup,
						{ name: name },
						children
					);
				}
			);
		}
	}]);

	return ArrayOf;
}(Component), _class4.propTypes = {
	children: childrenType,
	name: PropTypes.string.isRequired
}, _temp2)) || _class3;

export { ArrayOf as default };
